@@ -56,21 +56,18 @@ enum
 	LAST_SIGNAL
 };
 
-#define DMAP_MDNS_BROWSER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_BROWSER, DmapMdnsBrowserPrivate))
-
 static guint _signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_CODE (DmapMdnsBrowser,
-                         dmap_mdns_browser,
-                         G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (DmapMdnsBrowser));
+G_DEFINE_TYPE_WITH_PRIVATE (DmapMdnsBrowser,
+                            dmap_mdns_browser,
+                            G_TYPE_OBJECT);
 
 static void
 dmap_mdns_browser_init (DmapMdnsBrowser * browser)
 {
 	g_assert (NULL != browser);
 
-	browser->priv = DMAP_MDNS_BROWSER_GET_PRIVATE (browser);
+	browser->priv = dmap_mdns_browser_get_instance_private(browser);
 }
 
 static void
@@ -172,12 +169,12 @@ done:
 }
 
 static void
-_dns_service_browse_reply (DNSServiceRef sd_ref,
+_dns_service_browse_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
                            DNSServiceFlags flags,
                            uint32_t interface_index,
                            DNSServiceErrorType error_code,
                            const char *service_name,
-                           const char *regtype,
+                           G_GNUC_UNUSED const char *regtype,
                            const char *domain, void *udata)
 {
 	if (error_code != kDNSServiceErr_NoError) {
@@ -205,14 +202,15 @@ done:
 	return;
 }
 
+/*
 static void
-_dns_host_resolve_reply (DNSServiceRef sd_ref,
-                         DNSServiceFlags flags,
-                         uint32_t interface_index,
+_dns_host_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
+                         G_GNUC_UNUSED DNSServiceFlags flags,
+                         G_GNUC_UNUSED uint32_t interface_index,
                          DNSServiceErrorType error_code,
-                         const char *hostname,
+                         G_GNUC_UNUSED const char *hostname,
                          const struct sockaddr *address,
-                         uint32_t ttl,
+                         G_GNUC_UNUSED uint32_t ttl,
                          void *udata)
 {
 	ServiceContext *ctx = (ServiceContext *) udata;
@@ -242,9 +240,11 @@ _dns_host_resolve_reply (DNSServiceRef sd_ref,
 		break;
 	}
 }
+*/
 
 static gboolean
-_lookup_result_available_cb (GIOChannel * gio, GIOCondition condition,
+_lookup_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
+                             GIOCondition condition,
                              ServiceContext *context)
 {
 	gboolean fnval = FALSE;
@@ -292,15 +292,15 @@ _add_host_lookup_to_event_loop (ServiceContext *context)
 }
 
 static void
-_dns_service_resolve_reply (DNSServiceRef sd_ref,
+_dns_service_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
                             DNSServiceFlags flags,
                             uint32_t interface_index,
                             DNSServiceErrorType error_code,
                             const char *name,
-                            const char *host,
+                            G_GNUC_UNUSED const char *host,
                             uint16_t port,
-                            uint16_t txt_len,
-                            const char *txt_record,
+                            G_GNUC_UNUSED uint16_t txt_len,
+                            G_GNUC_UNUSED const char *txt_record,
                             void *udata)
 {
 	DNSServiceRef ref;
@@ -341,7 +341,8 @@ _dns_service_resolve_reply (DNSServiceRef sd_ref,
 }
 
 static gboolean
-_service_result_available_cb (GIOChannel * gio, GIOCondition condition,
+_service_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
+                              GIOCondition condition,
                               ServiceContext *context)
 {
 	gboolean fnval = FALSE;
@@ -383,8 +384,9 @@ _add_service_discovery_to_event_loop (ServiceContext *context)
 }
 
 static gboolean
-_browse_result_available_cb (GIOChannel * gio,
-                             GIOCondition condition, DmapMdnsBrowser * browser)
+_browse_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
+                             GIOCondition condition,
+                             DmapMdnsBrowser * browser)
 {
 	gboolean fnval = FALSE;
 
@@ -500,7 +502,7 @@ dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_added), NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE,
+			      NULL, G_TYPE_NONE,
 			      1, DMAP_TYPE_MDNS_SERVICE);
 
 	_signals[SERVICE_REMOVED] =
@@ -509,7 +511,7 @@ dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_removed), NULL, NULL,
-			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
+			      NULL, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 }
 
@@ -559,7 +561,8 @@ dmap_mdns_browser_start (DmapMdnsBrowser * browser, GError ** error)
 }
 
 gboolean
-dmap_mdns_browser_stop (DmapMdnsBrowser * browser, GError ** error)
+dmap_mdns_browser_stop (DmapMdnsBrowser * browser,
+                        G_GNUC_UNUSED GError ** error)
 {
 	if (NULL != browser->priv->sd_browse_ref) {
 		DNSServiceRefDeallocate (browser->priv->sd_browse_ref);
@@ -582,7 +585,7 @@ dmap_mdns_browser_error_quark (void)
 	return quark;
 }
 
-G_CONST_RETURN GSList *
+const GSList *
 dmap_mdns_browser_get_services (DmapMdnsBrowser * browser)
 {
 	g_assert(NULL != browser);
